==> openshift-model-5.0.1-sources.jar: io/fabric8/openshift/api/model/DeploymentCauseImageTriggerFluentImpl.java <==
package io.fabric8.openshift.api.model;

import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.model.ObjectReferenceFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectReference;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.model.ObjectReferenceBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

public class DeploymentCauseImageTriggerFluentImpl<A extends DeploymentCauseImageTriggerFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements DeploymentCauseImageTriggerFluent<A> {

    private io.fabric8.kubernetes.api.model.ObjectReferenceBuilder from;

    public DeploymentCauseImageTriggerFluentImpl() {
    }

    public DeploymentCauseImageTriggerFluentImpl(DeploymentCauseImageTrigger instance) {
        this.withFrom(instance.getFrom()); 
    }

    
/**
 * This method has been deprecated, please use method buildFrom instead.
 * @return The buildable object.
 */
@Deprecated public io.fabric8.kubernetes.api.model.ObjectReference getFrom() {
        return this.from!=null?this.from.build():null;
    }

    public io.fabric8.kubernetes.api.model.ObjectReference buildFrom() {
        return this.from!=null?this.from.build():null;
    }

    public A withFrom(io.fabric8.kubernetes.api.model.ObjectReference from) {
        _visitables.get("from").remove(this.from);
        if (from!=null){ this.from= new ObjectReferenceBuilder(from); _visitables.get("from").add(this.from);} return (A) this;
    }

    public Boolean hasFrom() {
        return this.from != null;
    }

    public DeploymentCauseImageTriggerFluent.FromNested<A> withNewFrom() {
        return new FromNestedImpl();
    }

    public DeploymentCauseImageTriggerFluent.FromNested<A> withNewFromLike(io.fabric8.kubernetes.api.model.ObjectReference item) {
        return new FromNestedImpl(item);
    }

    public DeploymentCauseImageTriggerFluent.FromNested<A> editFrom() {
        return withNewFromLike(getFrom());
    }

    public DeploymentCauseImageTriggerFluent.FromNested<A> editOrNewFrom() {
        return withNewFromLike(getFrom() != null ? getFrom(): new ObjectReferenceBuilder().build());
    }

    public DeploymentCauseImageTriggerFluent.FromNested<A> editOrNewFromLike(io.fabric8.kubernetes.api.model.ObjectReference item) {
        return withNewFromLike(getFrom() != null ? getFrom(): item);
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        DeploymentCauseImageTriggerFluentImpl that = (DeploymentCauseImageTriggerFluentImpl) o;
        if (from != null ? !from.equals(that.from) :that.from != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(from,  super.hashCode());
    }

    public class FromNestedImpl<N> extends io.fabric8.kubernetes.api.model.ObjectReferenceFluentImpl<DeploymentCauseImageTriggerFluent.FromNested<N>> implements DeploymentCauseImageTriggerFluent.FromNested<N>,io.fabric8.kubernetes.api.builder.Nested<N> {
        private final io.fabric8.kubernetes.api.model.ObjectReferenceBuilder builder;

            FromNestedImpl(io.fabric8.kubernetes.api.model.ObjectReference item) {
                this.builder = new ObjectReferenceBuilder(this, item);
                        
            }

            FromNestedImpl() {
                this.builder = new ObjectReferenceBuilder(this);
                        
            }

            public N and() {
                return (N) DeploymentCauseImageTriggerFluentImpl.this.withFrom(builder.build());
            }

            public N endFrom() {
                return and();
            }
    }


}

==> openshift-model-5.3.2-sources.jar: io/fabric8/openshift/api/model/DeploymentCauseImageTriggerFluentImpl.java <==
package io.fabric8.openshift.api.model;

import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.model.ObjectReferenceFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectReference;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.model.ObjectReferenceBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

public class DeploymentCauseImageTriggerFluentImpl<A extends DeploymentCauseImageTriggerFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements DeploymentCauseImageTriggerFluent<A> {

    private io.fabric8.kubernetes.api.model.ObjectReferenceBuilder from;

    public DeploymentCauseImageTriggerFluentImpl() {
    }

    public DeploymentCauseImageTriggerFluentImpl(DeploymentCauseImageTrigger instance) {
        this.withFrom(instance.getFrom()); 
    }

    
/**
 * This method has been deprecated, please use method buildFrom instead.
 * @return The buildable object.
 */
@Deprecated public io.fabric8.kubernetes.api.model.ObjectReference getFrom() {
        return this.from!=null?this.from.build():null;
    }

    public io.fabric8.kubernetes.api.model.ObjectReference buildFrom() {
        return this.from!=null?this.from.build():null;
    }

    public A withFrom(io.fabric8.kubernetes.api.model.ObjectReference from) {
        _visitables.get("from").remove(this.from);
        if (from!=null){ this.from= new ObjectReferenceBuilder(from); _visitables.get("from").add(this.from);} return (A) this;
    }

    public Boolean hasFrom() {
        return this.from != null;
    }

    public io.fabric8.openshift.api.model.DeploymentCauseImageTriggerFluent.FromNested<A> withNewFrom() {
        return new FromNestedImpl();
    }

    public io.fabric8.openshift.api.model.DeploymentCauseImageTriggerFluent.FromNested<A> withNewFromLike(io.fabric8.kubernetes.api.model.ObjectReference item) {
        return new FromNestedImpl(item);
    }

    public io.fabric8.openshift.api.model.DeploymentCauseImageTriggerFluent.FromNested<A> editFrom() {
        return withNewFromLike(getFrom());
    }

    public io.fabric8.openshift.api.model.DeploymentCauseImageTriggerFluent.FromNested<A> editOrNewFrom() {
        return withNewFromLike(getFrom() != null ? getFrom(): new ObjectReferenceBuilder().build());
    }

    public io.fabric8.openshift.api.model.DeploymentCauseImageTriggerFluent.FromNested<A> editOrNewFromLike(io.fabric8.kubernetes.api.model.ObjectReference item) {
        return withNewFromLike(getFrom() != null ? getFrom(): item);
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        DeploymentCauseImageTriggerFluentImpl that = (DeploymentCauseImageTriggerFluentImpl) o;
        if (from != null ? !from.equals(that.from) :that.from != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(from,  super.hashCode());
    }

    public class FromNestedImpl<N> extends io.fabric8.kubernetes.api.model.ObjectReferenceFluentImpl<io.fabric8.openshift.api.model.DeploymentCauseImageTriggerFluent.FromNested<N>> implements io.fabric8.openshift.api.model.DeploymentCauseImageTriggerFluent.FromNested<N>,io.fabric8.kubernetes.api.builder.Nested<N> {
        private final io.fabric8.kubernetes.api.model.ObjectReferenceBuilder builder;

            FromNestedImpl(io.fabric8.kubernetes.api.model.ObjectReference item) {
                this.builder = new ObjectReferenceBuilder(this, item);
                        
            }

            FromNestedImpl() {
                this.builder = new ObjectReferenceBuilder(this);
                        
            }

            public N and() {
                return (N) DeploymentCauseImageTriggerFluentImpl.this.withFrom(builder.build());
            }

            public N endFrom() {
                return and();
            }
    }


}
